@@ -69,7 +69,8 @@ class AWSCronExpressionValidator:
 
     @classmethod
     def slash_regex(cls, values: str) -> str:
-        return rf"((\*|[0-9]*[1-9][0-9]*)?\/{values})"  # Slash can be preceded by nothing, * or a natural number
+        return rf"((\*|{values})\/[0-9]*[1-9][0-9]*)"
+        # Slash can be preceded by * or a valid value and must be followed by an natural number as the increment.
 
     @classmethod
     def common_regex(cls, values: str) -> str:
